# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/cluster.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from grid.protos.grid.v1 import metadata_pb2 as grid_dot_v1_dot_metadata__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='grid/v1/cluster.proto',
  package='grid.v1',
  syntax='proto3',
  serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x15grid/v1/cluster.proto\x12\x07grid.v1\x1a\x16grid/v1/metadata.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19google/protobuf/any.proto\"\x92\x01\n\x07\x43luster\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x11.grid.v1.MetadataR\x08metadata\x12(\n\x04spec\x18\x02 \x01(\x0b\x32\x14.grid.v1.ClusterSpecR\x04spec\x12.\n\x06status\x18\x03 \x01(\x0b\x32\x16.grid.v1.ClusterStatusR\x06status\"\xd8\x03\n\x0b\x43lusterSpec\x12.\n\x06\x64river\x18\x01 \x01(\x0b\x32\x16.grid.v1.ClusterDriverR\x06\x64river\x12)\n\x10pause_automation\x18\x02 \x01(\x08R\x0fpauseAutomation\x12\x1a\n\x08internal\x18\x03 \x01(\x08R\x08internal\x12:\n\rdesired_state\x18\x04 \x01(\x0e\x32\x15.grid.v1.ClusterStateR\x0c\x64\x65siredState\x12\'\n\x0fgridlet_version\x18\x05 \x01(\tR\x0egridletVersion\x12\x17\n\x07user_id\x18\x06 \x01(\tR\x06userId\x12\x37\n\x0c\x63luster_type\x18\x07 \x01(\x0e\x32\x14.grid.v1.ClusterTypeR\x0b\x63lusterType\x12\x1f\n\x0b\x63ost_factor\x18\x08 \x01(\tR\ncostFactor\x12%\n\x0epadding_factor\x18\t \x01(\tR\rpaddingFactor\x12S\n\x13performance_profile\x18\n \x01(\x0e\x32\".grid.v1.ClusterPerformanceProfileR\x12performanceProfile\"\xc6\x01\n\rClusterDriver\x12\x32\n\x08\x65xternal\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00R\x08\x65xternal\x12\x42\n\nkubernetes\x18\x02 \x01(\x0b\x32 .grid.v1.KubernetesClusterDriverH\x00R\nkubernetes\x12\x33\n\x05slurm\x18\x03 \x01(\x0b\x32\x1b.grid.v1.SlurmClusterDriverH\x00R\x05slurmB\x08\n\x06\x64river\"\xca\x03\n\x17KubernetesClusterDriver\x12\x31\n\x03\x61ws\x18\x01 \x01(\x0b\x32\x1d.grid.v1.AWSClusterDriverSpecH\x00R\x03\x61ws\x12=\n\nkubeconfig\x18\x02 \x01(\x0b\x32\x1b.grid.v1.ExternalKubeconfigH\x00R\nkubeconfig\x12\x37\n\x05\x61zure\x18\x05 \x01(\x0b\x32\x1f.grid.v1.AzureClusterDriverSpecH\x00R\x05\x61zure\x12(\n\x10root_domain_name\x18\x03 \x01(\tR\x0erootDomainName\x12\x1c\n\tnamespace\x18\x04 \x01(\tR\tnamespace\x12k\n\x15\x65xtra_gridlet_env_var\x18\x06 \x03(\x0b\x32\x38.grid.v1.KubernetesClusterDriver.ExtraGridletEnvVarEntryR\x12\x65xtraGridletEnvVar\x1a\x45\n\x17\x45xtraGridletEnvVarEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x08\n\x06\x64river\"\xdb\x05\n\x14\x41WSClusterDriverSpec\x12\x16\n\x06region\x18\x01 \x01(\tR\x06region\x12\x19\n\x08role_arn\x18\x02 \x01(\tR\x07roleArn\x12\x1f\n\x0b\x65xternal_id\x18\x03 \x01(\tR\nexternalId\x12-\n\x12kubernetes_version\x18\x04 \x01(\tR\x11kubernetesVersion\x12<\n\x0einstance_types\x18\x05 \x03(\x0b\x32\x15.grid.v1.InstanceSpecR\rinstanceTypes\x12\x32\n\x15original_cluster_name\x18\x06 \x01(\tR\x13originalClusterName\x12\x1f\n\x0b\x62ucket_name\x18\x07 \x01(\tR\nbucketName\x12.\n\x13\x65nable_dns_firewall\x18\x10 \x01(\x08R\x11\x65nableDnsFirewall\x12&\n\x0finternal_gc_ttl\x18\x11 \x01(\tR\rinternalGcTtl\x12\x32\n\x15internal_test_cluster\x18\x12 \x01(\x08R\x13internalTestCluster\x12\x33\n\x15guardduty_integration\x18\x13 \x01(\x08R\x14guarddutyIntegration\x12\'\n\x10x_multi_az_count\x18\x15 \x01(\x05R\rxMultiAzCount\x12\x41\n\x1dmanagement_node_instance_type\x18\x16 \x01(\tR\x1amanagementNodeInstanceType\x12\x43\n\x1etensorboard_node_instance_type\x18\x17 \x01(\tR\x1btensorboardNodeInstanceType\x12;\n\x1a\x62uilder_node_instance_type\x18\x18 \x01(\tR\x17\x62uilderNodeInstanceType\"\xfa\x01\n\x16\x41zureClusterDriverSpec\x12\x16\n\x06region\x18\x01 \x01(\tR\x06region\x12\'\n\x0fsubscription_id\x18\x02 \x01(\tR\x0esubscriptionId\x12-\n\x12kubernetes_version\x18\x04 \x01(\tR\x11kubernetesVersion\x12<\n\x0einstance_types\x18\x05 \x03(\x0b\x32\x15.grid.v1.InstanceSpecR\rinstanceTypes\x12\x32\n\x15internal_test_cluster\x18\x12 \x01(\x08R\x13internalTestCluster\"h\n\x0cInstanceSpec\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x44\n\x1eoverprovisioned_ondemand_count\x18\x02 \x01(\rR\x1coverprovisionedOndemandCount\"4\n\x12\x45xternalKubeconfig\x12\x1e\n\nkubeconfig\x18\x01 \x01(\tR\nkubeconfig\"\x14\n\x12SlurmClusterDriver\"\x9a\x02\n\rClusterStatus\x12\x41\n\rdriver_status\x18\x01 \x01(\x0b\x32\x1c.grid.v1.ClusterDriverStatusR\x0c\x64riverStatus\x12+\n\x05phase\x18\x02 \x01(\x0e\x32\x15.grid.v1.ClusterStateR\x05phase\x12\x16\n\x06reason\x18\x03 \x01(\tR\x06reason\x12X\n\x1alast_healthcheck_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x18lastHealthcheckTimestamp\x12\'\n\x0fgridlet_version\x18\x05 \x01(\tR\x0egridletVersion\"\xcc\x01\n\x13\x43lusterDriverStatus\x12\x32\n\x08\x65xternal\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00R\x08\x65xternal\x12\x42\n\nkubernetes\x18\x02 \x01(\x0b\x32 .grid.v1.KubernetesClusterStatusH\x00R\nkubernetes\x12\x33\n\x05slurm\x18\x03 \x01(\x0b\x32\x1b.grid.v1.SlurmClusterStatusH\x00R\x05slurmB\x08\n\x06status\"\xf6\x03\n\x17KubernetesClusterStatus\x12&\n\x0f\x62\x61stion_host_ip\x18\x02 \x01(\tR\rbastionHostIp\x12$\n\x0essh_public_key\x18\x03 \x01(\tR\x0csshPublicKey\x12&\n\x0fssh_private_key\x18\x04 \x01(\tR\rsshPrivateKey\x12\x32\n\x03\x65ks\x18\x05 \x01(\x0b\x32\x1e.grid.v1.EKSCusterDriverStatusH\x00R\x03\x65ks\x12\x39\n\x05\x61zure\x18\t \x01(\x0b\x32!.grid.v1.AzureClusterDriverStatusH\x00R\x05\x61zure\x12\x45\n\x1eingress_load_balancer_hostname\x18\x06 \x01(\tH\x01R\x1bingressLoadBalancerHostname\x12\x39\n\x18ingress_load_balancer_ip\x18\x07 \x01(\tH\x01R\x15ingressLoadBalancerIp\x12\x30\n\x14ssh_gateway_hostname\x18\x08 \x01(\tR\x12sshGatewayHostname\x12&\n\x0fingress_ca_cert\x18\n \x01(\x0cR\ringressCaCertB\x0f\n\rdriver_statusB\t\n\x07ingress\"\xe3\x01\n\x15\x45KSCusterDriverStatus\x12(\n\x10gridlet_role_arn\x18\x02 \x01(\tR\x0egridletRoleArn\x12\x33\n\x16user_workload_role_arn\x18\x03 \x01(\tR\x13userWorkloadRoleArn\x12&\n\x0f\x65\x63r_registry_id\x18\x04 \x01(\tR\recrRegistryId\x12,\n\x12\x65\x63r_repository_uri\x18\x05 \x01(\tR\x10\x65\x63rRepositoryUri\x12\x15\n\x06vpc_id\x18\x06 \x01(\tR\x05vpcId\"\x1a\n\x18\x41zureClusterDriverStatus\"\x14\n\x12SlurmClusterStatus*t\n\x0b\x43lusterType\x12\x1c\n\x18\x43LUSTER_TYPE_UNSPECIFIED\x10\x00\x12\x17\n\x13\x43LUSTER_TYPE_LEGACY\x10\x01\x12\x17\n\x13\x43LUSTER_TYPE_GLOBAL\x10\x02\x12\x15\n\x11\x43LUSTER_TYPE_BYOC\x10\x03*\xb2\x01\n\x0c\x43lusterState\x12\x1d\n\x19\x43LUSTER_STATE_UNSPECIFIED\x10\x00\x12\x19\n\x15\x43LUSTER_STATE_PENDING\x10\x01\x12\x18\n\x14\x43LUSTER_STATE_QUEUED\x10\x02\x12\x19\n\x15\x43LUSTER_STATE_RUNNING\x10\x03\x12\x18\n\x14\x43LUSTER_STATE_FAILED\x10\x04\x12\x19\n\x15\x43LUSTER_STATE_DELETED\x10\x05*\x9e\x01\n\x19\x43lusterPerformanceProfile\x12+\n\'CLUSTER_PERFORMANCE_PROFILE_UNSPECIFIED\x10\x00\x12\'\n#CLUSTER_PERFORMANCE_PROFILE_DEFAULT\x10\x01\x12+\n\'CLUSTER_PERFORMANCE_PROFILE_COST_SAVING\x10\x02\x42\x32Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3'
  ,
  dependencies=[grid_dot_v1_dot_metadata__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,])

_CLUSTERTYPE = _descriptor.EnumDescriptor(
  name='ClusterType',
  full_name='grid.v1.ClusterType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CLUSTER_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLUSTER_TYPE_LEGACY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLUSTER_TYPE_GLOBAL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLUSTER_TYPE_BYOC', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3850,
  serialized_end=3966,
)
_sym_db.RegisterEnumDescriptor(_CLUSTERTYPE)

ClusterType = enum_type_wrapper.EnumTypeWrapper(_CLUSTERTYPE)
_CLUSTERSTATE = _descriptor.EnumDescriptor(
  name='ClusterState',
  full_name='grid.v1.ClusterState',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CLUSTER_STATE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLUSTER_STATE_PENDING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLUSTER_STATE_QUEUED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLUSTER_STATE_RUNNING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLUSTER_STATE_FAILED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLUSTER_STATE_DELETED', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3969,
  serialized_end=4147,
)
_sym_db.RegisterEnumDescriptor(_CLUSTERSTATE)

ClusterState = enum_type_wrapper.EnumTypeWrapper(_CLUSTERSTATE)
_CLUSTERPERFORMANCEPROFILE = _descriptor.EnumDescriptor(
  name='ClusterPerformanceProfile',
  full_name='grid.v1.ClusterPerformanceProfile',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CLUSTER_PERFORMANCE_PROFILE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLUSTER_PERFORMANCE_PROFILE_DEFAULT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLUSTER_PERFORMANCE_PROFILE_COST_SAVING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4150,
  serialized_end=4308,
)
_sym_db.RegisterEnumDescriptor(_CLUSTERPERFORMANCEPROFILE)

ClusterPerformanceProfile = enum_type_wrapper.EnumTypeWrapper(_CLUSTERPERFORMANCEPROFILE)
CLUSTER_TYPE_UNSPECIFIED = 0
CLUSTER_TYPE_LEGACY = 1
CLUSTER_TYPE_GLOBAL = 2
CLUSTER_TYPE_BYOC = 3
CLUSTER_STATE_UNSPECIFIED = 0
CLUSTER_STATE_PENDING = 1
CLUSTER_STATE_QUEUED = 2
CLUSTER_STATE_RUNNING = 3
CLUSTER_STATE_FAILED = 4
CLUSTER_STATE_DELETED = 5
CLUSTER_PERFORMANCE_PROFILE_UNSPECIFIED = 0
CLUSTER_PERFORMANCE_PROFILE_DEFAULT = 1
CLUSTER_PERFORMANCE_PROFILE_COST_SAVING = 2



_CLUSTER = _descriptor.Descriptor(
  name='Cluster',
  full_name='grid.v1.Cluster',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='grid.v1.Cluster.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='metadata', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spec', full_name='grid.v1.Cluster.spec', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='spec', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='grid.v1.Cluster.status', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=119,
  serialized_end=265,
)


_CLUSTERSPEC = _descriptor.Descriptor(
  name='ClusterSpec',
  full_name='grid.v1.ClusterSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='driver', full_name='grid.v1.ClusterSpec.driver', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='driver', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pause_automation', full_name='grid.v1.ClusterSpec.pause_automation', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='pauseAutomation', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='internal', full_name='grid.v1.ClusterSpec.internal', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='internal', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='desired_state', full_name='grid.v1.ClusterSpec.desired_state', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='desiredState', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gridlet_version', full_name='grid.v1.ClusterSpec.gridlet_version', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='gridletVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='grid.v1.ClusterSpec.user_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='userId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_type', full_name='grid.v1.ClusterSpec.cluster_type', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='clusterType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cost_factor', full_name='grid.v1.ClusterSpec.cost_factor', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='costFactor', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='padding_factor', full_name='grid.v1.ClusterSpec.padding_factor', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='paddingFactor', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='performance_profile', full_name='grid.v1.ClusterSpec.performance_profile', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='performanceProfile', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=268,
  serialized_end=740,
)


_CLUSTERDRIVER = _descriptor.Descriptor(
  name='ClusterDriver',
  full_name='grid.v1.ClusterDriver',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='external', full_name='grid.v1.ClusterDriver.external', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='external', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kubernetes', full_name='grid.v1.ClusterDriver.kubernetes', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='kubernetes', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slurm', full_name='grid.v1.ClusterDriver.slurm', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='slurm', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='driver', full_name='grid.v1.ClusterDriver.driver',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=743,
  serialized_end=941,
)


_KUBERNETESCLUSTERDRIVER_EXTRAGRIDLETENVVARENTRY = _descriptor.Descriptor(
  name='ExtraGridletEnvVarEntry',
  full_name='grid.v1.KubernetesClusterDriver.ExtraGridletEnvVarEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='grid.v1.KubernetesClusterDriver.ExtraGridletEnvVarEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='grid.v1.KubernetesClusterDriver.ExtraGridletEnvVarEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1323,
  serialized_end=1392,
)

_KUBERNETESCLUSTERDRIVER = _descriptor.Descriptor(
  name='KubernetesClusterDriver',
  full_name='grid.v1.KubernetesClusterDriver',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='aws', full_name='grid.v1.KubernetesClusterDriver.aws', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='aws', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kubeconfig', full_name='grid.v1.KubernetesClusterDriver.kubeconfig', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='kubeconfig', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='azure', full_name='grid.v1.KubernetesClusterDriver.azure', index=2,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='azure', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='root_domain_name', full_name='grid.v1.KubernetesClusterDriver.root_domain_name', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rootDomainName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='grid.v1.KubernetesClusterDriver.namespace', index=4,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='namespace', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extra_gridlet_env_var', full_name='grid.v1.KubernetesClusterDriver.extra_gridlet_env_var', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='extraGridletEnvVar', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_KUBERNETESCLUSTERDRIVER_EXTRAGRIDLETENVVARENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='driver', full_name='grid.v1.KubernetesClusterDriver.driver',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=944,
  serialized_end=1402,
)


_AWSCLUSTERDRIVERSPEC = _descriptor.Descriptor(
  name='AWSClusterDriverSpec',
  full_name='grid.v1.AWSClusterDriverSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='region', full_name='grid.v1.AWSClusterDriverSpec.region', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='region', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='role_arn', full_name='grid.v1.AWSClusterDriverSpec.role_arn', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='roleArn', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='external_id', full_name='grid.v1.AWSClusterDriverSpec.external_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='externalId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kubernetes_version', full_name='grid.v1.AWSClusterDriverSpec.kubernetes_version', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='kubernetesVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instance_types', full_name='grid.v1.AWSClusterDriverSpec.instance_types', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='instanceTypes', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='original_cluster_name', full_name='grid.v1.AWSClusterDriverSpec.original_cluster_name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='originalClusterName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucket_name', full_name='grid.v1.AWSClusterDriverSpec.bucket_name', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='bucketName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_dns_firewall', full_name='grid.v1.AWSClusterDriverSpec.enable_dns_firewall', index=7,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='enableDnsFirewall', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='internal_gc_ttl', full_name='grid.v1.AWSClusterDriverSpec.internal_gc_ttl', index=8,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='internalGcTtl', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='internal_test_cluster', full_name='grid.v1.AWSClusterDriverSpec.internal_test_cluster', index=9,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='internalTestCluster', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='guardduty_integration', full_name='grid.v1.AWSClusterDriverSpec.guardduty_integration', index=10,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='guarddutyIntegration', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='x_multi_az_count', full_name='grid.v1.AWSClusterDriverSpec.x_multi_az_count', index=11,
      number=21, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='xMultiAzCount', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='management_node_instance_type', full_name='grid.v1.AWSClusterDriverSpec.management_node_instance_type', index=12,
      number=22, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='managementNodeInstanceType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tensorboard_node_instance_type', full_name='grid.v1.AWSClusterDriverSpec.tensorboard_node_instance_type', index=13,
      number=23, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='tensorboardNodeInstanceType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='builder_node_instance_type', full_name='grid.v1.AWSClusterDriverSpec.builder_node_instance_type', index=14,
      number=24, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='builderNodeInstanceType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1405,
  serialized_end=2136,
)


_AZURECLUSTERDRIVERSPEC = _descriptor.Descriptor(
  name='AzureClusterDriverSpec',
  full_name='grid.v1.AzureClusterDriverSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='region', full_name='grid.v1.AzureClusterDriverSpec.region', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='region', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subscription_id', full_name='grid.v1.AzureClusterDriverSpec.subscription_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='subscriptionId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kubernetes_version', full_name='grid.v1.AzureClusterDriverSpec.kubernetes_version', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='kubernetesVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instance_types', full_name='grid.v1.AzureClusterDriverSpec.instance_types', index=3,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='instanceTypes', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='internal_test_cluster', full_name='grid.v1.AzureClusterDriverSpec.internal_test_cluster', index=4,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='internalTestCluster', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2139,
  serialized_end=2389,
)


_INSTANCESPEC = _descriptor.Descriptor(
  name='InstanceSpec',
  full_name='grid.v1.InstanceSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='grid.v1.InstanceSpec.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='overprovisioned_ondemand_count', full_name='grid.v1.InstanceSpec.overprovisioned_ondemand_count', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='overprovisionedOndemandCount', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2391,
  serialized_end=2495,
)


_EXTERNALKUBECONFIG = _descriptor.Descriptor(
  name='ExternalKubeconfig',
  full_name='grid.v1.ExternalKubeconfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='kubeconfig', full_name='grid.v1.ExternalKubeconfig.kubeconfig', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='kubeconfig', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2497,
  serialized_end=2549,
)


_SLURMCLUSTERDRIVER = _descriptor.Descriptor(
  name='SlurmClusterDriver',
  full_name='grid.v1.SlurmClusterDriver',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2551,
  serialized_end=2571,
)


_CLUSTERSTATUS = _descriptor.Descriptor(
  name='ClusterStatus',
  full_name='grid.v1.ClusterStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='driver_status', full_name='grid.v1.ClusterStatus.driver_status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='driverStatus', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='phase', full_name='grid.v1.ClusterStatus.phase', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='phase', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='grid.v1.ClusterStatus.reason', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='reason', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_healthcheck_timestamp', full_name='grid.v1.ClusterStatus.last_healthcheck_timestamp', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='lastHealthcheckTimestamp', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gridlet_version', full_name='grid.v1.ClusterStatus.gridlet_version', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='gridletVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2574,
  serialized_end=2856,
)


_CLUSTERDRIVERSTATUS = _descriptor.Descriptor(
  name='ClusterDriverStatus',
  full_name='grid.v1.ClusterDriverStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='external', full_name='grid.v1.ClusterDriverStatus.external', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='external', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kubernetes', full_name='grid.v1.ClusterDriverStatus.kubernetes', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='kubernetes', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slurm', full_name='grid.v1.ClusterDriverStatus.slurm', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='slurm', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='status', full_name='grid.v1.ClusterDriverStatus.status',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2859,
  serialized_end=3063,
)


_KUBERNETESCLUSTERSTATUS = _descriptor.Descriptor(
  name='KubernetesClusterStatus',
  full_name='grid.v1.KubernetesClusterStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bastion_host_ip', full_name='grid.v1.KubernetesClusterStatus.bastion_host_ip', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='bastionHostIp', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ssh_public_key', full_name='grid.v1.KubernetesClusterStatus.ssh_public_key', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sshPublicKey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ssh_private_key', full_name='grid.v1.KubernetesClusterStatus.ssh_private_key', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sshPrivateKey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eks', full_name='grid.v1.KubernetesClusterStatus.eks', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='eks', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='azure', full_name='grid.v1.KubernetesClusterStatus.azure', index=4,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='azure', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ingress_load_balancer_hostname', full_name='grid.v1.KubernetesClusterStatus.ingress_load_balancer_hostname', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='ingressLoadBalancerHostname', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ingress_load_balancer_ip', full_name='grid.v1.KubernetesClusterStatus.ingress_load_balancer_ip', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='ingressLoadBalancerIp', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ssh_gateway_hostname', full_name='grid.v1.KubernetesClusterStatus.ssh_gateway_hostname', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sshGatewayHostname', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ingress_ca_cert', full_name='grid.v1.KubernetesClusterStatus.ingress_ca_cert', index=8,
      number=10, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='ingressCaCert', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='driver_status', full_name='grid.v1.KubernetesClusterStatus.driver_status',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='ingress', full_name='grid.v1.KubernetesClusterStatus.ingress',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3066,
  serialized_end=3568,
)


_EKSCUSTERDRIVERSTATUS = _descriptor.Descriptor(
  name='EKSCusterDriverStatus',
  full_name='grid.v1.EKSCusterDriverStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gridlet_role_arn', full_name='grid.v1.EKSCusterDriverStatus.gridlet_role_arn', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='gridletRoleArn', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_workload_role_arn', full_name='grid.v1.EKSCusterDriverStatus.user_workload_role_arn', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='userWorkloadRoleArn', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ecr_registry_id', full_name='grid.v1.EKSCusterDriverStatus.ecr_registry_id', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='ecrRegistryId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ecr_repository_uri', full_name='grid.v1.EKSCusterDriverStatus.ecr_repository_uri', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='ecrRepositoryUri', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vpc_id', full_name='grid.v1.EKSCusterDriverStatus.vpc_id', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='vpcId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3571,
  serialized_end=3798,
)


_AZURECLUSTERDRIVERSTATUS = _descriptor.Descriptor(
  name='AzureClusterDriverStatus',
  full_name='grid.v1.AzureClusterDriverStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3800,
  serialized_end=3826,
)


_SLURMCLUSTERSTATUS = _descriptor.Descriptor(
  name='SlurmClusterStatus',
  full_name='grid.v1.SlurmClusterStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3828,
  serialized_end=3848,
)

_CLUSTER.fields_by_name['metadata'].message_type = grid_dot_v1_dot_metadata__pb2._METADATA
_CLUSTER.fields_by_name['spec'].message_type = _CLUSTERSPEC
_CLUSTER.fields_by_name['status'].message_type = _CLUSTERSTATUS
_CLUSTERSPEC.fields_by_name['driver'].message_type = _CLUSTERDRIVER
_CLUSTERSPEC.fields_by_name['desired_state'].enum_type = _CLUSTERSTATE
_CLUSTERSPEC.fields_by_name['cluster_type'].enum_type = _CLUSTERTYPE
_CLUSTERSPEC.fields_by_name['performance_profile'].enum_type = _CLUSTERPERFORMANCEPROFILE
_CLUSTERDRIVER.fields_by_name['external'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_CLUSTERDRIVER.fields_by_name['kubernetes'].message_type = _KUBERNETESCLUSTERDRIVER
_CLUSTERDRIVER.fields_by_name['slurm'].message_type = _SLURMCLUSTERDRIVER
_CLUSTERDRIVER.oneofs_by_name['driver'].fields.append(
  _CLUSTERDRIVER.fields_by_name['external'])
_CLUSTERDRIVER.fields_by_name['external'].containing_oneof = _CLUSTERDRIVER.oneofs_by_name['driver']
_CLUSTERDRIVER.oneofs_by_name['driver'].fields.append(
  _CLUSTERDRIVER.fields_by_name['kubernetes'])
_CLUSTERDRIVER.fields_by_name['kubernetes'].containing_oneof = _CLUSTERDRIVER.oneofs_by_name['driver']
_CLUSTERDRIVER.oneofs_by_name['driver'].fields.append(
  _CLUSTERDRIVER.fields_by_name['slurm'])
_CLUSTERDRIVER.fields_by_name['slurm'].containing_oneof = _CLUSTERDRIVER.oneofs_by_name['driver']
_KUBERNETESCLUSTERDRIVER_EXTRAGRIDLETENVVARENTRY.containing_type = _KUBERNETESCLUSTERDRIVER
_KUBERNETESCLUSTERDRIVER.fields_by_name['aws'].message_type = _AWSCLUSTERDRIVERSPEC
_KUBERNETESCLUSTERDRIVER.fields_by_name['kubeconfig'].message_type = _EXTERNALKUBECONFIG
_KUBERNETESCLUSTERDRIVER.fields_by_name['azure'].message_type = _AZURECLUSTERDRIVERSPEC
_KUBERNETESCLUSTERDRIVER.fields_by_name['extra_gridlet_env_var'].message_type = _KUBERNETESCLUSTERDRIVER_EXTRAGRIDLETENVVARENTRY
_KUBERNETESCLUSTERDRIVER.oneofs_by_name['driver'].fields.append(
  _KUBERNETESCLUSTERDRIVER.fields_by_name['aws'])
_KUBERNETESCLUSTERDRIVER.fields_by_name['aws'].containing_oneof = _KUBERNETESCLUSTERDRIVER.oneofs_by_name['driver']
_KUBERNETESCLUSTERDRIVER.oneofs_by_name['driver'].fields.append(
  _KUBERNETESCLUSTERDRIVER.fields_by_name['kubeconfig'])
_KUBERNETESCLUSTERDRIVER.fields_by_name['kubeconfig'].containing_oneof = _KUBERNETESCLUSTERDRIVER.oneofs_by_name['driver']
_KUBERNETESCLUSTERDRIVER.oneofs_by_name['driver'].fields.append(
  _KUBERNETESCLUSTERDRIVER.fields_by_name['azure'])
_KUBERNETESCLUSTERDRIVER.fields_by_name['azure'].containing_oneof = _KUBERNETESCLUSTERDRIVER.oneofs_by_name['driver']
_AWSCLUSTERDRIVERSPEC.fields_by_name['instance_types'].message_type = _INSTANCESPEC
_AZURECLUSTERDRIVERSPEC.fields_by_name['instance_types'].message_type = _INSTANCESPEC
_CLUSTERSTATUS.fields_by_name['driver_status'].message_type = _CLUSTERDRIVERSTATUS
_CLUSTERSTATUS.fields_by_name['phase'].enum_type = _CLUSTERSTATE
_CLUSTERSTATUS.fields_by_name['last_healthcheck_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CLUSTERDRIVERSTATUS.fields_by_name['external'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_CLUSTERDRIVERSTATUS.fields_by_name['kubernetes'].message_type = _KUBERNETESCLUSTERSTATUS
_CLUSTERDRIVERSTATUS.fields_by_name['slurm'].message_type = _SLURMCLUSTERSTATUS
_CLUSTERDRIVERSTATUS.oneofs_by_name['status'].fields.append(
  _CLUSTERDRIVERSTATUS.fields_by_name['external'])
_CLUSTERDRIVERSTATUS.fields_by_name['external'].containing_oneof = _CLUSTERDRIVERSTATUS.oneofs_by_name['status']
_CLUSTERDRIVERSTATUS.oneofs_by_name['status'].fields.append(
  _CLUSTERDRIVERSTATUS.fields_by_name['kubernetes'])
_CLUSTERDRIVERSTATUS.fields_by_name['kubernetes'].containing_oneof = _CLUSTERDRIVERSTATUS.oneofs_by_name['status']
_CLUSTERDRIVERSTATUS.oneofs_by_name['status'].fields.append(
  _CLUSTERDRIVERSTATUS.fields_by_name['slurm'])
_CLUSTERDRIVERSTATUS.fields_by_name['slurm'].containing_oneof = _CLUSTERDRIVERSTATUS.oneofs_by_name['status']
_KUBERNETESCLUSTERSTATUS.fields_by_name['eks'].message_type = _EKSCUSTERDRIVERSTATUS
_KUBERNETESCLUSTERSTATUS.fields_by_name['azure'].message_type = _AZURECLUSTERDRIVERSTATUS
_KUBERNETESCLUSTERSTATUS.oneofs_by_name['driver_status'].fields.append(
  _KUBERNETESCLUSTERSTATUS.fields_by_name['eks'])
_KUBERNETESCLUSTERSTATUS.fields_by_name['eks'].containing_oneof = _KUBERNETESCLUSTERSTATUS.oneofs_by_name['driver_status']
_KUBERNETESCLUSTERSTATUS.oneofs_by_name['driver_status'].fields.append(
  _KUBERNETESCLUSTERSTATUS.fields_by_name['azure'])
_KUBERNETESCLUSTERSTATUS.fields_by_name['azure'].containing_oneof = _KUBERNETESCLUSTERSTATUS.oneofs_by_name['driver_status']
_KUBERNETESCLUSTERSTATUS.oneofs_by_name['ingress'].fields.append(
  _KUBERNETESCLUSTERSTATUS.fields_by_name['ingress_load_balancer_hostname'])
_KUBERNETESCLUSTERSTATUS.fields_by_name['ingress_load_balancer_hostname'].containing_oneof = _KUBERNETESCLUSTERSTATUS.oneofs_by_name['ingress']
_KUBERNETESCLUSTERSTATUS.oneofs_by_name['ingress'].fields.append(
  _KUBERNETESCLUSTERSTATUS.fields_by_name['ingress_load_balancer_ip'])
_KUBERNETESCLUSTERSTATUS.fields_by_name['ingress_load_balancer_ip'].containing_oneof = _KUBERNETESCLUSTERSTATUS.oneofs_by_name['ingress']
DESCRIPTOR.message_types_by_name['Cluster'] = _CLUSTER
DESCRIPTOR.message_types_by_name['ClusterSpec'] = _CLUSTERSPEC
DESCRIPTOR.message_types_by_name['ClusterDriver'] = _CLUSTERDRIVER
DESCRIPTOR.message_types_by_name['KubernetesClusterDriver'] = _KUBERNETESCLUSTERDRIVER
DESCRIPTOR.message_types_by_name['AWSClusterDriverSpec'] = _AWSCLUSTERDRIVERSPEC
DESCRIPTOR.message_types_by_name['AzureClusterDriverSpec'] = _AZURECLUSTERDRIVERSPEC
DESCRIPTOR.message_types_by_name['InstanceSpec'] = _INSTANCESPEC
DESCRIPTOR.message_types_by_name['ExternalKubeconfig'] = _EXTERNALKUBECONFIG
DESCRIPTOR.message_types_by_name['SlurmClusterDriver'] = _SLURMCLUSTERDRIVER
DESCRIPTOR.message_types_by_name['ClusterStatus'] = _CLUSTERSTATUS
DESCRIPTOR.message_types_by_name['ClusterDriverStatus'] = _CLUSTERDRIVERSTATUS
DESCRIPTOR.message_types_by_name['KubernetesClusterStatus'] = _KUBERNETESCLUSTERSTATUS
DESCRIPTOR.message_types_by_name['EKSCusterDriverStatus'] = _EKSCUSTERDRIVERSTATUS
DESCRIPTOR.message_types_by_name['AzureClusterDriverStatus'] = _AZURECLUSTERDRIVERSTATUS
DESCRIPTOR.message_types_by_name['SlurmClusterStatus'] = _SLURMCLUSTERSTATUS
DESCRIPTOR.enum_types_by_name['ClusterType'] = _CLUSTERTYPE
DESCRIPTOR.enum_types_by_name['ClusterState'] = _CLUSTERSTATE
DESCRIPTOR.enum_types_by_name['ClusterPerformanceProfile'] = _CLUSTERPERFORMANCEPROFILE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Cluster = _reflection.GeneratedProtocolMessageType('Cluster', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTER,
  '__module__' : 'grid.v1.cluster_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.Cluster)
  })
_sym_db.RegisterMessage(Cluster)

ClusterSpec = _reflection.GeneratedProtocolMessageType('ClusterSpec', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERSPEC,
  '__module__' : 'grid.v1.cluster_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.ClusterSpec)
  })
_sym_db.RegisterMessage(ClusterSpec)

ClusterDriver = _reflection.GeneratedProtocolMessageType('ClusterDriver', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERDRIVER,
  '__module__' : 'grid.v1.cluster_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.ClusterDriver)
  })
_sym_db.RegisterMessage(ClusterDriver)

KubernetesClusterDriver = _reflection.GeneratedProtocolMessageType('KubernetesClusterDriver', (_message.Message,), {

  'ExtraGridletEnvVarEntry' : _reflection.GeneratedProtocolMessageType('ExtraGridletEnvVarEntry', (_message.Message,), {
    'DESCRIPTOR' : _KUBERNETESCLUSTERDRIVER_EXTRAGRIDLETENVVARENTRY,
    '__module__' : 'grid.v1.cluster_pb2'
    # @@protoc_insertion_point(class_scope:grid.v1.KubernetesClusterDriver.ExtraGridletEnvVarEntry)
    })
  ,
  'DESCRIPTOR' : _KUBERNETESCLUSTERDRIVER,
  '__module__' : 'grid.v1.cluster_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.KubernetesClusterDriver)
  })
_sym_db.RegisterMessage(KubernetesClusterDriver)
_sym_db.RegisterMessage(KubernetesClusterDriver.ExtraGridletEnvVarEntry)

AWSClusterDriverSpec = _reflection.GeneratedProtocolMessageType('AWSClusterDriverSpec', (_message.Message,), {
  'DESCRIPTOR' : _AWSCLUSTERDRIVERSPEC,
  '__module__' : 'grid.v1.cluster_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.AWSClusterDriverSpec)
  })
_sym_db.RegisterMessage(AWSClusterDriverSpec)

AzureClusterDriverSpec = _reflection.GeneratedProtocolMessageType('AzureClusterDriverSpec', (_message.Message,), {
  'DESCRIPTOR' : _AZURECLUSTERDRIVERSPEC,
  '__module__' : 'grid.v1.cluster_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.AzureClusterDriverSpec)
  })
_sym_db.RegisterMessage(AzureClusterDriverSpec)

InstanceSpec = _reflection.GeneratedProtocolMessageType('InstanceSpec', (_message.Message,), {
  'DESCRIPTOR' : _INSTANCESPEC,
  '__module__' : 'grid.v1.cluster_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.InstanceSpec)
  })
_sym_db.RegisterMessage(InstanceSpec)

ExternalKubeconfig = _reflection.GeneratedProtocolMessageType('ExternalKubeconfig', (_message.Message,), {
  'DESCRIPTOR' : _EXTERNALKUBECONFIG,
  '__module__' : 'grid.v1.cluster_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.ExternalKubeconfig)
  })
_sym_db.RegisterMessage(ExternalKubeconfig)

SlurmClusterDriver = _reflection.GeneratedProtocolMessageType('SlurmClusterDriver', (_message.Message,), {
  'DESCRIPTOR' : _SLURMCLUSTERDRIVER,
  '__module__' : 'grid.v1.cluster_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.SlurmClusterDriver)
  })
_sym_db.RegisterMessage(SlurmClusterDriver)

ClusterStatus = _reflection.GeneratedProtocolMessageType('ClusterStatus', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERSTATUS,
  '__module__' : 'grid.v1.cluster_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.ClusterStatus)
  })
_sym_db.RegisterMessage(ClusterStatus)

ClusterDriverStatus = _reflection.GeneratedProtocolMessageType('ClusterDriverStatus', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERDRIVERSTATUS,
  '__module__' : 'grid.v1.cluster_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.ClusterDriverStatus)
  })
_sym_db.RegisterMessage(ClusterDriverStatus)

KubernetesClusterStatus = _reflection.GeneratedProtocolMessageType('KubernetesClusterStatus', (_message.Message,), {
  'DESCRIPTOR' : _KUBERNETESCLUSTERSTATUS,
  '__module__' : 'grid.v1.cluster_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.KubernetesClusterStatus)
  })
_sym_db.RegisterMessage(KubernetesClusterStatus)

EKSCusterDriverStatus = _reflection.GeneratedProtocolMessageType('EKSCusterDriverStatus', (_message.Message,), {
  'DESCRIPTOR' : _EKSCUSTERDRIVERSTATUS,
  '__module__' : 'grid.v1.cluster_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.EKSCusterDriverStatus)
  })
_sym_db.RegisterMessage(EKSCusterDriverStatus)

AzureClusterDriverStatus = _reflection.GeneratedProtocolMessageType('AzureClusterDriverStatus', (_message.Message,), {
  'DESCRIPTOR' : _AZURECLUSTERDRIVERSTATUS,
  '__module__' : 'grid.v1.cluster_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.AzureClusterDriverStatus)
  })
_sym_db.RegisterMessage(AzureClusterDriverStatus)

SlurmClusterStatus = _reflection.GeneratedProtocolMessageType('SlurmClusterStatus', (_message.Message,), {
  'DESCRIPTOR' : _SLURMCLUSTERSTATUS,
  '__module__' : 'grid.v1.cluster_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.SlurmClusterStatus)
  })
_sym_db.RegisterMessage(SlurmClusterStatus)


DESCRIPTOR._options = None
_KUBERNETESCLUSTERDRIVER_EXTRAGRIDLETENVVARENTRY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/resource.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='grid/v1/resource.proto',
  package='grid.v1',
  syntax='proto3',
  serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x16grid/v1/resource.proto\x12\x07grid.v1\"\xbd\x01\n\tResources\x12\x10\n\x03\x63pu\x18\x01 \x01(\x04R\x03\x63pu\x12\x10\n\x03gpu\x18\x02 \x01(\x04R\x03gpu\x12\x1d\n\nstorage_gb\x18\x03 \x01(\x04R\tstorageGb\x12\x33\n\x05\x65xtra\x18\x04 \x03(\x0b\x32\x1d.grid.v1.Resources.ExtraEntryR\x05\x65xtra\x1a\x38\n\nExtraEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x32Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3'
)




_RESOURCES_EXTRAENTRY = _descriptor.Descriptor(
  name='ExtraEntry',
  full_name='grid.v1.Resources.ExtraEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='grid.v1.Resources.ExtraEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='grid.v1.Resources.ExtraEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=169,
  serialized_end=225,
)

_RESOURCES = _descriptor.Descriptor(
  name='Resources',
  full_name='grid.v1.Resources',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cpu', full_name='grid.v1.Resources.cpu', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='cpu', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gpu', full_name='grid.v1.Resources.gpu', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='gpu', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storage_gb', full_name='grid.v1.Resources.storage_gb', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='storageGb', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extra', full_name='grid.v1.Resources.extra', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='extra', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RESOURCES_EXTRAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=36,
  serialized_end=225,
)

_RESOURCES_EXTRAENTRY.containing_type = _RESOURCES
_RESOURCES.fields_by_name['extra'].message_type = _RESOURCES_EXTRAENTRY
DESCRIPTOR.message_types_by_name['Resources'] = _RESOURCES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Resources = _reflection.GeneratedProtocolMessageType('Resources', (_message.Message,), {

  'ExtraEntry' : _reflection.GeneratedProtocolMessageType('ExtraEntry', (_message.Message,), {
    'DESCRIPTOR' : _RESOURCES_EXTRAENTRY,
    '__module__' : 'grid.v1.resource_pb2'
    # @@protoc_insertion_point(class_scope:grid.v1.Resources.ExtraEntry)
    })
  ,
  'DESCRIPTOR' : _RESOURCES,
  '__module__' : 'grid.v1.resource_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.Resources)
  })
_sym_db.RegisterMessage(Resources)
_sym_db.RegisterMessage(Resources.ExtraEntry)


DESCRIPTOR._options = None
_RESOURCES_EXTRAENTRY._options = None
# @@protoc_insertion_point(module_scope)



# coding: utf-8

"""
    external/v1/external_session_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from grid.openapi.api_client import ApiClient


class ClusterServiceApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def cluster_service_create_cluster(self, body, **kwargs):  # noqa: E501
        """cluster_service_create_cluster  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cluster_service_create_cluster(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1CreateClusterRequest body: (required)
        :return: V1CreateClusterResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.cluster_service_create_cluster_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.cluster_service_create_cluster_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def cluster_service_create_cluster_with_http_info(self, body, **kwargs):  # noqa: E501
        """cluster_service_create_cluster  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cluster_service_create_cluster_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1CreateClusterRequest body: (required)
        :return: V1CreateClusterResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cluster_service_create_cluster" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `cluster_service_create_cluster`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/core/clusters', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1CreateClusterResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def cluster_service_delete_cluster(self, id, **kwargs):  # noqa: E501
        """cluster_service_delete_cluster  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cluster_service_delete_cluster(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: V1DeleteClusterResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.cluster_service_delete_cluster_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.cluster_service_delete_cluster_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def cluster_service_delete_cluster_with_http_info(self, id, **kwargs):  # noqa: E501
        """cluster_service_delete_cluster  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cluster_service_delete_cluster_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: V1DeleteClusterResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cluster_service_delete_cluster" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `cluster_service_delete_cluster`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/core/clusters/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1DeleteClusterResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def cluster_service_get_cluster(self, id, **kwargs):  # noqa: E501
        """cluster_service_get_cluster  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cluster_service_get_cluster(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: V1GetClusterResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.cluster_service_get_cluster_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.cluster_service_get_cluster_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def cluster_service_get_cluster_with_http_info(self, id, **kwargs):  # noqa: E501
        """cluster_service_get_cluster  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cluster_service_get_cluster_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: V1GetClusterResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cluster_service_get_cluster" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `cluster_service_get_cluster`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/core/clusters/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1GetClusterResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def cluster_service_list_cluster_instance_types(self, id, **kwargs):  # noqa: E501
        """cluster_service_list_cluster_instance_types  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cluster_service_list_cluster_instance_types(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: V1ListClusterInstanceTypesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.cluster_service_list_cluster_instance_types_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.cluster_service_list_cluster_instance_types_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def cluster_service_list_cluster_instance_types_with_http_info(self, id, **kwargs):  # noqa: E501
        """cluster_service_list_cluster_instance_types  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cluster_service_list_cluster_instance_types_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: V1ListClusterInstanceTypesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cluster_service_list_cluster_instance_types" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `cluster_service_list_cluster_instance_types`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/core/clusters/{id}/instance-types', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1ListClusterInstanceTypesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def cluster_service_list_clusters(self, **kwargs):  # noqa: E501
        """cluster_service_list_clusters  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cluster_service_list_clusters(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] phase_in:
        :param list[str] phase_not_in:
        :param list[str] cluster_type_in:
        :param list[str] cluster_type_not_in:
        :return: V1ListClustersResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.cluster_service_list_clusters_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.cluster_service_list_clusters_with_http_info(**kwargs)  # noqa: E501
            return data

    def cluster_service_list_clusters_with_http_info(self, **kwargs):  # noqa: E501
        """cluster_service_list_clusters  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cluster_service_list_clusters_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] phase_in:
        :param list[str] phase_not_in:
        :param list[str] cluster_type_in:
        :param list[str] cluster_type_not_in:
        :return: V1ListClustersResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['phase_in', 'phase_not_in', 'cluster_type_in', 'cluster_type_not_in']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cluster_service_list_clusters" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'phase_in' in params:
            query_params.append(('phaseIn', params['phase_in']))  # noqa: E501
            collection_formats['phaseIn'] = 'multi'  # noqa: E501
        if 'phase_not_in' in params:
            query_params.append(('phaseNotIn', params['phase_not_in']))  # noqa: E501
            collection_formats['phaseNotIn'] = 'multi'  # noqa: E501
        if 'cluster_type_in' in params:
            query_params.append(('clusterTypeIn', params['cluster_type_in']))  # noqa: E501
            collection_formats['clusterTypeIn'] = 'multi'  # noqa: E501
        if 'cluster_type_not_in' in params:
            query_params.append(('clusterTypeNotIn', params['cluster_type_not_in']))  # noqa: E501
            collection_formats['clusterTypeNotIn'] = 'multi'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/core/clusters', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1ListClustersResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def cluster_service_update_cluster(self, id, body, **kwargs):  # noqa: E501
        """cluster_service_update_cluster  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cluster_service_update_cluster(id, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param Body body: (required)
        :return: V1UpdateClusterResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.cluster_service_update_cluster_with_http_info(id, body, **kwargs)  # noqa: E501
        else:
            (data) = self.cluster_service_update_cluster_with_http_info(id, body, **kwargs)  # noqa: E501
            return data

    def cluster_service_update_cluster_with_http_info(self, id, body, **kwargs):  # noqa: E501
        """cluster_service_update_cluster  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cluster_service_update_cluster_with_http_info(id, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param Body body: (required)
        :return: V1UpdateClusterResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cluster_service_update_cluster" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `cluster_service_update_cluster`")  # noqa: E501
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `cluster_service_update_cluster`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/core/clusters/{id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1UpdateClusterResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/metadata.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='grid/v1/metadata.proto',
  package='grid.v1',
  syntax='proto3',
  serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x16grid/v1/metadata.proto\x12\x07grid.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\x87\x04\n\x08Metadata\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12I\n\x12\x63reation_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x11\x63reationTimestamp\x12I\n\x12\x64\x65letion_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x11\x64\x65letionTimestamp\x12)\n\x10resource_version\x18\x05 \x01(\tR\x0fresourceVersion\x12\x35\n\x06labels\x18\x06 \x03(\x0b\x32\x1d.grid.v1.Metadata.LabelsEntryR\x06labels\x12\x44\n\x0b\x61nnotations\x18\x07 \x03(\x0b\x32\".grid.v1.Metadata.AnnotationsEntryR\x0b\x61nnotations\x12\x1e\n\nfinalizers\x18\x08 \x03(\tR\nfinalizers\x1a\x39\n\x0bLabelsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a>\n\x10\x41nnotationsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x32Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_METADATA_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='grid.v1.Metadata.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='grid.v1.Metadata.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='grid.v1.Metadata.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=467,
  serialized_end=524,
)

_METADATA_ANNOTATIONSENTRY = _descriptor.Descriptor(
  name='AnnotationsEntry',
  full_name='grid.v1.Metadata.AnnotationsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='grid.v1.Metadata.AnnotationsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='grid.v1.Metadata.AnnotationsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=526,
  serialized_end=588,
)

_METADATA = _descriptor.Descriptor(
  name='Metadata',
  full_name='grid.v1.Metadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='grid.v1.Metadata.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='grid.v1.Metadata.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='creation_timestamp', full_name='grid.v1.Metadata.creation_timestamp', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='creationTimestamp', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deletion_timestamp', full_name='grid.v1.Metadata.deletion_timestamp', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='deletionTimestamp', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_version', full_name='grid.v1.Metadata.resource_version', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='grid.v1.Metadata.labels', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='labels', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='annotations', full_name='grid.v1.Metadata.annotations', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='annotations', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='finalizers', full_name='grid.v1.Metadata.finalizers', index=7,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='finalizers', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_METADATA_LABELSENTRY, _METADATA_ANNOTATIONSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=69,
  serialized_end=588,
)

_METADATA_LABELSENTRY.containing_type = _METADATA
_METADATA_ANNOTATIONSENTRY.containing_type = _METADATA
_METADATA.fields_by_name['creation_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_METADATA.fields_by_name['deletion_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_METADATA.fields_by_name['labels'].message_type = _METADATA_LABELSENTRY
_METADATA.fields_by_name['annotations'].message_type = _METADATA_ANNOTATIONSENTRY
DESCRIPTOR.message_types_by_name['Metadata'] = _METADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Metadata = _reflection.GeneratedProtocolMessageType('Metadata', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _METADATA_LABELSENTRY,
    '__module__' : 'grid.v1.metadata_pb2'
    # @@protoc_insertion_point(class_scope:grid.v1.Metadata.LabelsEntry)
    })
  ,

  'AnnotationsEntry' : _reflection.GeneratedProtocolMessageType('AnnotationsEntry', (_message.Message,), {
    'DESCRIPTOR' : _METADATA_ANNOTATIONSENTRY,
    '__module__' : 'grid.v1.metadata_pb2'
    # @@protoc_insertion_point(class_scope:grid.v1.Metadata.AnnotationsEntry)
    })
  ,
  'DESCRIPTOR' : _METADATA,
  '__module__' : 'grid.v1.metadata_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.Metadata)
  })
_sym_db.RegisterMessage(Metadata)
_sym_db.RegisterMessage(Metadata.LabelsEntry)
_sym_db.RegisterMessage(Metadata.AnnotationsEntry)


DESCRIPTOR._options = None
_METADATA_LABELSENTRY._options = None
_METADATA_ANNOTATIONSENTRY._options = None
# @@protoc_insertion_point(module_scope)



# coding: utf-8

"""
    external/v1/external_session_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from grid.openapi.configuration import Configuration


class V1RunActions(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'on_build': 'list[str]',
        'on_build_end': 'list[str]',
        'on_build_start': 'list[str]',
        'on_experiment_end': 'list[str]',
        'on_experiment_start': 'list[str]'
    }

    attribute_map = {
        'on_build': 'onBuild',
        'on_build_end': 'onBuildEnd',
        'on_build_start': 'onBuildStart',
        'on_experiment_end': 'onExperimentEnd',
        'on_experiment_start': 'onExperimentStart'
    }

    def __init__(self, on_build=None, on_build_end=None, on_build_start=None, on_experiment_end=None, on_experiment_start=None, _configuration=None):  # noqa: E501
        """V1RunActions - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._on_build = None
        self._on_build_end = None
        self._on_build_start = None
        self._on_experiment_end = None
        self._on_experiment_start = None
        self.discriminator = None

        if on_build is not None:
            self.on_build = on_build
        if on_build_end is not None:
            self.on_build_end = on_build_end
        if on_build_start is not None:
            self.on_build_start = on_build_start
        if on_experiment_end is not None:
            self.on_experiment_end = on_experiment_end
        if on_experiment_start is not None:
            self.on_experiment_start = on_experiment_start

    @property
    def on_build(self):
        """Gets the on_build of this V1RunActions.  # noqa: E501


        :return: The on_build of this V1RunActions.  # noqa: E501
        :rtype: list[str]
        """
        return self._on_build

    @on_build.setter
    def on_build(self, on_build):
        """Sets the on_build of this V1RunActions.


        :param on_build: The on_build of this V1RunActions.  # noqa: E501
        :type: list[str]
        """

        self._on_build = on_build

    @property
    def on_build_end(self):
        """Gets the on_build_end of this V1RunActions.  # noqa: E501

        commands passed to the image builder which are interpreted as RUN commands in a Dockerfile. Executes after installing dependencies from package manager.  # noqa: E501

        :return: The on_build_end of this V1RunActions.  # noqa: E501
        :rtype: list[str]
        """
        return self._on_build_end

    @on_build_end.setter
    def on_build_end(self, on_build_end):
        """Sets the on_build_end of this V1RunActions.

        commands passed to the image builder which are interpreted as RUN commands in a Dockerfile. Executes after installing dependencies from package manager.  # noqa: E501

        :param on_build_end: The on_build_end of this V1RunActions.  # noqa: E501
        :type: list[str]
        """

        self._on_build_end = on_build_end

    @property
    def on_build_start(self):
        """Gets the on_build_start of this V1RunActions.  # noqa: E501

        commands passed to the image builder which are interpreted as RUN commands in a Dockerfile. Executes before installing dependencies from package manager.  # noqa: E501

        :return: The on_build_start of this V1RunActions.  # noqa: E501
        :rtype: list[str]
        """
        return self._on_build_start

    @on_build_start.setter
    def on_build_start(self, on_build_start):
        """Sets the on_build_start of this V1RunActions.

        commands passed to the image builder which are interpreted as RUN commands in a Dockerfile. Executes before installing dependencies from package manager.  # noqa: E501

        :param on_build_start: The on_build_start of this V1RunActions.  # noqa: E501
        :type: list[str]
        """

        self._on_build_start = on_build_start

    @property
    def on_experiment_end(self):
        """Gets the on_experiment_end of this V1RunActions.  # noqa: E501

        on_experiment_end allows users to specify commands that need to be executed sequentially after the main experiment process ends. This command will be executed on every experiment that the run creates.  # noqa: E501

        :return: The on_experiment_end of this V1RunActions.  # noqa: E501
        :rtype: list[str]
        """
        return self._on_experiment_end

    @on_experiment_end.setter
    def on_experiment_end(self, on_experiment_end):
        """Sets the on_experiment_end of this V1RunActions.

        on_experiment_end allows users to specify commands that need to be executed sequentially after the main experiment process ends. This command will be executed on every experiment that the run creates.  # noqa: E501

        :param on_experiment_end: The on_experiment_end of this V1RunActions.  # noqa: E501
        :type: list[str]
        """

        self._on_experiment_end = on_experiment_end

    @property
    def on_experiment_start(self):
        """Gets the on_experiment_start of this V1RunActions.  # noqa: E501

        on_experiment_start allows users to specify commands that need to be executed sequentially before the main experiment process starts. This command will be executed on every experiment that the run creates.  # noqa: E501

        :return: The on_experiment_start of this V1RunActions.  # noqa: E501
        :rtype: list[str]
        """
        return self._on_experiment_start

    @on_experiment_start.setter
    def on_experiment_start(self, on_experiment_start):
        """Sets the on_experiment_start of this V1RunActions.

        on_experiment_start allows users to specify commands that need to be executed sequentially before the main experiment process starts. This command will be executed on every experiment that the run creates.  # noqa: E501

        :param on_experiment_start: The on_experiment_start of this V1RunActions.  # noqa: E501
        :type: list[str]
        """

        self._on_experiment_start = on_experiment_start

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1RunActions, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1RunActions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1RunActions):
            return True

        return self.to_dict() != other.to_dict()



from contextlib import contextmanager
import os
from pathlib import Path


@contextmanager
def set_directory(path: Path):
    """Sets the cwd within the context

    Args:
        path (Path): The path to the cwd

    Yields:
        None
    """

    origin = Path().absolute()
    try:
        os.chdir(path)
        yield
    finally:
        os.chdir(origin)



# coding: utf-8

"""
    external/v1/external_session_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from grid.openapi.configuration import Configuration


class Externalv1DatastoreSpec(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cluster_id': 'str',
        'size_mib': 'int',
        'source': 'str',
        'uploaded_at': 'datetime',
        'user_id': 'str',
        'version': 'int'
    }

    attribute_map = {
        'cluster_id': 'clusterId',
        'size_mib': 'sizeMib',
        'source': 'source',
        'uploaded_at': 'uploadedAt',
        'user_id': 'userId',
        'version': 'version'
    }

    def __init__(self, cluster_id=None, size_mib=None, source=None, uploaded_at=None, user_id=None, version=None, _configuration=None):  # noqa: E501
        """Externalv1DatastoreSpec - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._cluster_id = None
        self._size_mib = None
        self._source = None
        self._uploaded_at = None
        self._user_id = None
        self._version = None
        self.discriminator = None

        if cluster_id is not None:
            self.cluster_id = cluster_id
        if size_mib is not None:
            self.size_mib = size_mib
        if source is not None:
            self.source = source
        if uploaded_at is not None:
            self.uploaded_at = uploaded_at
        if user_id is not None:
            self.user_id = user_id
        if version is not None:
            self.version = version

    @property
    def cluster_id(self):
        """Gets the cluster_id of this Externalv1DatastoreSpec.  # noqa: E501


        :return: The cluster_id of this Externalv1DatastoreSpec.  # noqa: E501
        :rtype: str
        """
        return self._cluster_id

    @cluster_id.setter
    def cluster_id(self, cluster_id):
        """Sets the cluster_id of this Externalv1DatastoreSpec.


        :param cluster_id: The cluster_id of this Externalv1DatastoreSpec.  # noqa: E501
        :type: str
        """

        self._cluster_id = cluster_id

    @property
    def size_mib(self):
        """Gets the size_mib of this Externalv1DatastoreSpec.  # noqa: E501


        :return: The size_mib of this Externalv1DatastoreSpec.  # noqa: E501
        :rtype: int
        """
        return self._size_mib

    @size_mib.setter
    def size_mib(self, size_mib):
        """Sets the size_mib of this Externalv1DatastoreSpec.


        :param size_mib: The size_mib of this Externalv1DatastoreSpec.  # noqa: E501
        :type: int
        """

        self._size_mib = size_mib

    @property
    def source(self):
        """Gets the source of this Externalv1DatastoreSpec.  # noqa: E501


        :return: The source of this Externalv1DatastoreSpec.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this Externalv1DatastoreSpec.


        :param source: The source of this Externalv1DatastoreSpec.  # noqa: E501
        :type: str
        """

        self._source = source

    @property
    def uploaded_at(self):
        """Gets the uploaded_at of this Externalv1DatastoreSpec.  # noqa: E501


        :return: The uploaded_at of this Externalv1DatastoreSpec.  # noqa: E501
        :rtype: datetime
        """
        return self._uploaded_at

    @uploaded_at.setter
    def uploaded_at(self, uploaded_at):
        """Sets the uploaded_at of this Externalv1DatastoreSpec.


        :param uploaded_at: The uploaded_at of this Externalv1DatastoreSpec.  # noqa: E501
        :type: datetime
        """

        self._uploaded_at = uploaded_at

    @property
    def user_id(self):
        """Gets the user_id of this Externalv1DatastoreSpec.  # noqa: E501


        :return: The user_id of this Externalv1DatastoreSpec.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this Externalv1DatastoreSpec.


        :param user_id: The user_id of this Externalv1DatastoreSpec.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def version(self):
        """Gets the version of this Externalv1DatastoreSpec.  # noqa: E501


        :return: The version of this Externalv1DatastoreSpec.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this Externalv1DatastoreSpec.


        :param version: The version of this Externalv1DatastoreSpec.  # noqa: E501
        :type: int
        """

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Externalv1DatastoreSpec, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Externalv1DatastoreSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Externalv1DatastoreSpec):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import annotations

import ast
from datetime import datetime, timezone
import typing
from typing import Dict, Optional

import click
from dateutil.parser import parse as date_string_parse
from gql import Client, gql
from rich.progress import BarColumn, Progress, TextColumn

from grid.cli.exceptions import ResourceNotFound
import grid.cli.globals as env
from grid.cli.observables.base import BaseObservable, TASK_CLASS_IGNORE, TASK_CLASS_MAPPING
from grid.cli.utilities import get_abs_time_difference, string_format_timedelta

if typing.TYPE_CHECKING:
    from grid.cli.core import Team


def get_sessions(client: Client, team: Optional['Team'] = None) -> Dict:
    query = gql(
        """
    query GetInteractiveNodes ($teamId: ID){
        getInteractiveNodes(teamId: $teamId) {
            interactiveNodeId
            interactiveNodeName
            clusterId
            createdAt
            jupyterUrl
            status
            desiredState
            config {
                diskSize
                instanceType
                datastoreName
                datastoreVersion
                datastoreMountDir
            }
            userDetails {
                username
            }
        }
    }
    """
    )
    if team:
        params = {'teamId': team.id}  # noqa
    else:
        params = {'teamId': None}
    result = client.execute(query, variable_values=params)
    if not result['getInteractiveNodes']:
        raise ResourceNotFound
    return result


class InteractiveNode(BaseObservable):
    """
    Base observable for a Grid interactive node.

    Parameters
    ----------
    client: Client
        GQL client
    """
    def __init__(self, client: Client):
        self.client = client

        super().__init__(client=client, spinner_load_type="Interactive Nodes")

    # TODO: This isn't currently used anywhere. It may be useful to also
    #  show pre-run status for tasks related to creating an interactive node.
    #  New changes like teams/collaboration are not implemented for this func
    def _get_task_status(self, interactive_node_id: str):  # pragma: no cover
        """
        Gets task status for a given interactive node.

        Parameters
        ----------
        interactive_node_id: str
            Interactive node ID.
        """
        self.spinner.start()

        query = gql(
            """
        query GetInteractiveTaskStatus ($interactiveNodeId: ID!) {
            getInteractiveTaskStatus(interactiveNodeId: $interactiveNodeId) {
                status
                message
                dependencies {
                    taskId
                    status
                    taskType
                    message
                    error
                }
            }
        }
        """
        )
        params = {'interactiveNodeId': interactive_node_id}

        try:
            result = self.client.execute(query, variable_values=params)
        except Exception as e:  # skipcq: PYL-W0703
            message = ast.literal_eval(str(e))['message']
            self.spinner.fail("✘")
            raise click.ClickException(message)

        # Gets dependenceis.
        dependencies = result['getRunTaskStatus']['dependencies']

        #  Figure out the status of each task.
        dependency_data = {}
        for task in dependencies:
            if task['taskType'] in TASK_CLASS_IGNORE:
                continue

            dependency_data[task['taskType']] = {
                'status': task['status'],
                'error': task['error'],
                'message': task['message'],
                'status_message': TASK_CLASS_MAPPING[task['taskType']]
            }

        #  Display the status of setting-up the cluster & environment
        #  to the user.
        self.spinner.text = 'Done!'
        self.spinner.ok("✔")

        #  Show message if there's an error in a pre-start task.
        all_status = [s['status'] for s in dependency_data.values()]
        if any(s == 'failed' for s in all_status) and \
                not env.SHOW_PROCESS_STATUS_DETAILS:
            click.echo(
                f'''
        The Interactive Node "{interactive_node_id}" failed to start due to a setup error.
        You can see the errors by running

            grid status {interactive_node_id} --details

            '''
            )

        #  Create progress bar.
        click.echo('\n')
        with Progress(
            TextColumn("[bold blue]{task.description}", justify="left"), BarColumn(bar_width=55),
            "[self.progress.percentage]{task.percentage:>3.1f}%"
        ) as progress_bar:

            #  Render progress bar based on finished tasks.
            task_id = progress_bar.add_task('Creating Interactive Node', start=True, total=len(all_status))

            progress = sum(1 for s in all_status if s == 'finished')
            progress_bar.update(task_id, advance=progress)

        #  If there's an error with creating a cluster, then
        #  print that error to the terminal.
        if env.SHOW_PROCESS_STATUS_DETAILS:
            for key, value in dependency_data.items():
                if value.get('error'):
                    styled_key = click.style(TASK_CLASS_MAPPING[key], fg='red')
                    error = value.get('error')
                    for line in error.splitlines():
                        click.echo(f'[{styled_key}] {line}')
                else:
                    styled_key = click.style(TASK_CLASS_MAPPING[key], fg='green')
                    message = value.get('message')
                    click.echo(f'[{styled_key}] {message} ... ')

    def get(self, is_global: Optional[bool] = False):
        self.spinner.start()
        sessions = []

        # Fetching team's sessions if asked
        if is_global:
            # TODO Refactor this when the we continue the work on SDK
            from grid.cli.core.team import Team
            try:
                teams = Team.get_all()
            except Exception as e:
                teams = []
                self.spinner.fail("✘")
                if env.DEBUG:
                    click.echo(e)

            for team in teams:
                try:
                    team_sessions = get_sessions(self.client, team)
                    sessions.append(team_sessions)
                except ResourceNotFound:
                    # No sessions found
                    pass
                except Exception as e:
                    self.spinner.fail("✘")
                    if env.DEBUG:
                        click.echo(e)
        else:
            # Fetching user session
            try:
                user_session = get_sessions(self.client)
            except ResourceNotFound:
                # No sessions found
                pass
            except Exception as e:
                self.spinner.fail("✘")
                if env.DEBUG:
                    click.echo(e)
            else:
                sessions.append(user_session)

        # Create table with results.
        table_rows = 0
        if is_global:
            table_cols = ['Session', 'Status', 'Created By', 'Instance Type', 'Duration', 'URL']
        else:
            table_cols = ['Session', 'Status', 'Instance Type', 'Duration', 'URL']
        table = BaseObservable.create_table(columns=table_cols)

        for result in sessions:
            for row in result['getInteractiveNodes']:
                url = row['jupyterUrl']

                # Calculate how long the interactive node has been up.
                created_at = date_string_parse(row['createdAt'])
                delta = get_abs_time_difference(datetime.now(timezone.utc), created_at)
                duration_str = string_format_timedelta(delta)

                # Add rows to table. Accounts for a series of transition
                # states.
                if row['status'] == 'finished':
                    status = 'ready'
                elif row['status'] == 'paused' and row['desiredState'] == 'RUNNING':
                    status = 'resuming'
                elif row['status'] != 'paused' and row['desiredState'] == 'PAUSED':
                    status = 'pausing'
                elif row['status'] != 'deleted' and row['desiredState'] == 'DELETED':
                    status = 'deleting'
                else:
                    status = row['status']

                # Replace anything that doesn't have data with
                # a placeholder '-'.
                if is_global:
                    username = row['userDetails']['username'] if row['userDetails'] else None
                    all_rows = [
                        row['interactiveNodeName'], status, username, row['config']['instanceType'], duration_str, url
                    ]
                else:
                    all_rows = [row['interactiveNodeName'], status, row['config']['instanceType'], duration_str, url]
                all_rows = ['-' if not r else r for r in all_rows]
                table.add_row(*all_rows)

                # Adds iterator
                table_rows += 1

        #  Close the spinner.
        self.spinner.stop()

        # If there are no nodes active, add a
        # placeholder row indicating that.
        if not table_rows:
            table.add_row("None Active.", *[" " for i in range(len(table_cols) - 1)])

        # Print table
        self.console.print(table)

    def follow(self, is_global: Optional[bool] = False):  # pragma: no cover
        pass
